from enum import IntEnum
from enum import unique


@unique
class CalculationType(IntEnum):
    BOUNDARY_NODE = -1
    EMBEDDED = 0
    ISOLATED = 1
    CONNECTED = 2
    BROAD_CRESTED = 3  # only orifices + weirs, corresponds
    SHORT_CRESTED = 4  # only orifices + weirs
    DOUBLE_CONNECTED = 5


@unique
class NodeType(IntEnum):
    NODE_2D_OPEN_WATER = 1
    NODE_2D_GROUNDWATER = 2
    NODE_1D_NO_STORAGE = 3
    NODE_1D_STORAGE = 4
    NODE_2D_BOUNDARIES = 5
    NODE_2D_GROUNDWATER_BOUNDARIES = 6
    NODE_1D_BOUNDARIES = 7


@unique
class LineType(IntEnum):  # for kcu (calculation_type of a line)
    LINE_1D_EMBEDDED = int(CalculationType.EMBEDDED)
    LINE_1D_ISOLATED = int(CalculationType.ISOLATED)
    LINE_1D_CONNECTED = int(CalculationType.CONNECTED)
    LINE_1D_LONG_CRESTED = int(CalculationType.BROAD_CRESTED)
    LINE_1D_SHORT_CRESTED = int(CalculationType.SHORT_CRESTED)
    LINE_1D_DOUBLE_CONNECTED = int(CalculationType.DOUBLE_CONNECTED)
    LINE_1D2D_SINGLE_CONNECTED_WITH_STORAGE = 51
    LINE_1D2D_SINGLE_CONNECTED_WITHOUT_STORAGE = 52
    LINE_1D2D_DOUBLE_CONNECTED_WITH_STORAGE = 53
    LINE_1D2D_DOUBLE_CONNECTED_WITHOUT_STORAGE = 54
    LINE_1D2D_POSSIBLE_BREACH = 55
    LINE_1D2D_ACTIVE_BREACH = 56
    LINE_1D2D_GROUNDWATER_OPEN_WATER = 57
    LINE_1D2D_GROUNDWATER_SEWER = 58  # diff to 57?
    LINE_2D_U = 98
    LINE_2D_V = 99
    LINE_2D = 100
    LINE_2D_OBSTACLE = 101  # levee
    LINE_2D_VERTICAL = 150
    LINE_2D_GROUNDWATER = -150
    LINE_2D_BOUNDARY_200 = 200
    LINE_2D_BOUNDARY_300 = 300
    LINE_2D_BOUNDARY_400 = 400
    LINE_2D_BOUNDARY_500 = 500


@unique
class ContentType(IntEnum):
    TYPE_V2_PIPE = 1
    TYPE_V2_CHANNEL = 2
    TYPE_V2_CULVERT = 3
    TYPE_V2_ORIFICE = 4
    TYPE_V2_WEIR = 5
    TYPE_V2_MANHOLE = 6
    TYPE_V2_PUMPSTATION = 7
    TYPE_V2_LEVEE = 8
    TYPE_V2_1D_LATERAL = 9
    TYPE_V2_1D_BOUNDARY_CONDITIONS = 10
    TYPE_V2_2D_BOUNDARY_CONDITIONS = 11
    TYPE_V2_CONNECTION_NODES = 12
    TYPE_V2_BREACH = 13
    TYPE_V2_CROSS_SECTION_DEF = 14
    TYPE_V2_CROSS_SECTION_LOCATION = 15
    TYPE_V2_ADDED_CALCULATION_POINT = 16
    TYPE_V2_WINDSHIELD = 17


@unique
class FrictionType(IntEnum):
    CHEZY = 1
    MANNING = 2


@unique
class CrossSectionShape(IntEnum):
    # TODO Check valus, 0 possibly means "CLOSED_RECTANGLE"
    RECTANGLE = 1
    CIRCLE = 2
    EGG = 3
    TABULATED_RECTANGLE = 5
    TABULATED_TRAPEZIUM = 6


@unique
class ManholeIndicator(IntEnum):
    INSPECTION = 0
    OUTLET = 1
    PUMP = 2
